==> strela-java-sdk-0.0.2-sources.jar: MinecraftServerStatus.java <==
package dev.strela.v1;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"ingame","playerCount","ready"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
public class MinecraftServerStatus implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
     * Important: Run "make" to regenerate code after modifying this file
     */
    @com.fasterxml.jackson.annotation.JsonProperty("ingame")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("INSERT ADDITIONAL STATUS FIELD - define observed state of cluster\nImportant: Run \"make\" to regenerate code after modifying this file")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Boolean ingame;

    public Boolean getIngame() {
        return ingame;
    }

    public void setIngame(Boolean ingame) {
        this.ingame = ingame;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("playerCount")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Long playerCount;

    public Long getPlayerCount() {
        return playerCount;
    }

    public void setPlayerCount(Long playerCount) {
        this.playerCount = playerCount;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("ready")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Boolean ready;

    public Boolean getReady() {
        return ready;
    }

    public void setReady(Boolean ready) {
        this.ready = ready;
    }
}

==> strela-java-sdk-0.0.4-sources.jar: MinecraftServerStatus.java <==
package dev.strela.v1;

@com.fasterxml.jackson.annotation.JsonInclude(com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL)
@com.fasterxml.jackson.annotation.JsonPropertyOrder({"ingame","playerCount","ready","readyTime"})
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@javax.annotation.processing.Generated("io.fabric8.java.generator.CRGeneratorRunner")
public class MinecraftServerStatus implements io.fabric8.kubernetes.api.model.KubernetesResource {

    /**
     * INSERT ADDITIONAL STATUS FIELD - define observed state of cluster
     * Important: Run "make" to regenerate code after modifying this file
     */
    @com.fasterxml.jackson.annotation.JsonProperty("ingame")
    @com.fasterxml.jackson.annotation.JsonPropertyDescription("INSERT ADDITIONAL STATUS FIELD - define observed state of cluster\nImportant: Run \"make\" to regenerate code after modifying this file")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Boolean ingame;

    public Boolean getIngame() {
        return ingame;
    }

    public void setIngame(Boolean ingame) {
        this.ingame = ingame;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("playerCount")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Long playerCount;

    public Long getPlayerCount() {
        return playerCount;
    }

    public void setPlayerCount(Long playerCount) {
        this.playerCount = playerCount;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("ready")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private Boolean ready;

    public Boolean getReady() {
        return ready;
    }

    public void setReady(Boolean ready) {
        this.ready = ready;
    }

    @com.fasterxml.jackson.annotation.JsonProperty("readyTime")
    @com.fasterxml.jackson.annotation.JsonSetter(nulls = com.fasterxml.jackson.annotation.Nulls.SKIP)
    private java.time.ZonedDateTime readyTime;

    @com.fasterxml.jackson.annotation.JsonFormat(pattern = "yyyy-MM-dd'T'HH:mm:ssVV")
    public java.time.ZonedDateTime getReadyTime() {
        return readyTime;
    }

    @com.fasterxml.jackson.annotation.JsonFormat(pattern = "yyyy-MM-dd'T'HH:mm:ss[XXX][VV]")
    public void setReadyTime(java.time.ZonedDateTime readyTime) {
        this.readyTime = readyTime;
    }
}
